@@ -1,6 +1,6 @@
 __all__ = ["SENTINEL1_COLLECTION_ID", "VV", "VH", "IW", "ASCENDING", "DESCENDING"]
 
-SENTINEL1_COLLECTION_ID = "COPERNICUS/S1_GRD"
+SENTINEL1_COLLECTION_ID = "COPERNICUS/S1_GRD_FLOAT"
 VV = "VV"
 VH = "VH"
 IW = "IW"
